@@ -12,7 +12,7 @@
 ##############################################################################
 """Access control support
 
-$Id: Role.py 30356 2005-05-15 15:56:18Z yuppie $
+$Id: Role.py 73418 2007-03-21 11:48:43Z mj $
 """
 from cgi import escape
 
@@ -22,6 +22,7 @@ import Globals, ExtensionClass, PermissionMapping, Products
 from App.Common import aq_base
 
 from Permission import Permission
+from requestmethod import postonly
 
 
 DEFAULTMAXLISTUSERS=250
@@ -141,6 +142,7 @@ class RoleManager(ExtensionClass.Base, PermissionMapping.RoleManager):
             p.setRole(role_to_manage, name in permissions)
 
         if REQUEST is not None: return self.manage_access(REQUEST)
+    manage_role = postonly(manage_role)
 
     manage_acquiredForm=DTMLFile('dtml/acquiredEdit', globals(),
                                  management_view='Security',
@@ -160,6 +162,7 @@ class RoleManager(ExtensionClass.Base, PermissionMapping.RoleManager):
             else:                   p.setRoles(tuple(roles))
 
         if REQUEST is not None: return self.manage_access(REQUEST)
+    manage_acquiredPermissions = postonly(manage_acquiredPermissions)
 
     manage_permissionForm=DTMLFile('dtml/permissionEdit', globals(),
                                    management_view='Security',
@@ -188,6 +191,7 @@ class RoleManager(ExtensionClass.Base, PermissionMapping.RoleManager):
         raise ValueError, (
             "The permission <em>%s</em> is invalid." %
                 escape(permission_to_manage))
+    manage_permission = postonly(manage_permission)
 
     _normal_manage_access=DTMLFile('dtml/access', globals())
 
@@ -232,6 +236,7 @@ class RoleManager(ExtensionClass.Base, PermissionMapping.RoleManager):
             title  ='Success!',
             message='Your changes have been saved',
             action ='manage_access')
+    manage_changePermissions = postonly(manage_changePermissions)
 
     def permissionsOfRole(self, role):
         """Used by management screen.
@@ -365,6 +370,7 @@ class RoleManager(ExtensionClass.Base, PermissionMapping.RoleManager):
         if REQUEST is not None:
             stat='Your changes have been saved.'
             return self.manage_listLocalRoles(self, REQUEST, stat=stat)
+    manage_addLocalRoles = postonly(manage_addLocalRoles)
 
     def manage_setLocalRoles(self, userid, roles, REQUEST=None):
         """Set local roles for a user."""
@@ -378,6 +384,7 @@ class RoleManager(ExtensionClass.Base, PermissionMapping.RoleManager):
         if REQUEST is not None:
             stat='Your changes have been saved.'
             return self.manage_listLocalRoles(self, REQUEST, stat=stat)
+    manage_setLocalRoles = postonly(manage_setLocalRoles)
 
     def manage_delLocalRoles(self, userids, REQUEST=None):
         """Remove all local roles for a user."""
@@ -391,6 +398,7 @@ class RoleManager(ExtensionClass.Base, PermissionMapping.RoleManager):
         if REQUEST is not None:
             stat='Your changes have been saved.'
             return self.manage_listLocalRoles(self, REQUEST, stat=stat)
+    manage_delLocalRoles = postonly(manage_delLocalRoles)
 
     #------------------------------------------------------------
 
@@ -485,6 +493,7 @@ class RoleManager(ExtensionClass.Base, PermissionMapping.RoleManager):
         self.__ac_roles__=tuple(data)
         if REQUEST is not None:
             return self.manage_access(REQUEST)
+    _addRole = postonly(_addRole)
 
     def _delRoles(self, roles, REQUEST=None):
         if not roles:
@@ -499,6 +508,7 @@ class RoleManager(ExtensionClass.Base, PermissionMapping.RoleManager):
         self.__ac_roles__=tuple(data)
         if REQUEST is not None:
             return self.manage_access(REQUEST)
+    _delRoles = postonly(_delRoles)
 
     def _has_user_defined_role(self, role):
         return role in self.__ac_roles__
