@@ -10,10 +10,11 @@
 # FOR A PARTICULAR PURPOSE
 #
 ##############################################################################
-"""API Module for access to the security policy / manager.
+'''API module to set the security policy
+
+
+$Id: SecurityManager.py 24763 2004-05-17 05:59:28Z philikon $'''
 
-$Id: SecurityManager.py,v 1.13.70.1 2004/01/08 23:33:43 tseaver Exp $
-"""
 from AccessControl import ImplPython as _ImplPython
 from AccessControl.SimpleObjectPolicies import _noroles
 
@@ -28,4 +29,5 @@ def setSecurityPolicy(aSecurityPolicy):
     _ImplPython._defaultPolicy = aSecurityPolicy
     return last
 
+
 # AccessControl.Implementation inserts SecurityManager.
