@@ -23,6 +23,7 @@ from Acquisition import Implicit
 from OFS.SimpleItem import Item
 from base64 import decodestring
 from App.ImageFile import ImageFile
+from requestmethod import postonly
 from Role import RoleManager, DEFAULTMAXLISTUSERS
 from PermissionRole import _what_not_even_god_should_do, rolesForPermissionOn
 import AuthEncoding
@@ -527,28 +528,33 @@ class BasicUserFolder(Implicit, Persistent, Navigation, Tabs, RoleManager,
     # Authors of custom user folders don't need to do anything special to
     # support these - they will just call the appropriate '_' methods that
     # user folder subclasses already implement.
-    def userFolderAddUser(self, name, password, roles, domains, **kw):
+    def userFolderAddUser(self, name, password, roles, domains,
+                          REQUEST=None, **kw):
         """API method for creating a new user object. Note that not all
            user folder implementations support dynamic creation of user
            objects."""
         if hasattr(self, '_doAddUser'):
             return self._doAddUser(name, password, roles, domains, **kw)
         raise NotImplementedError
+    userFolderAddUser = postonly(userFolderAddUser)
 
-    def userFolderEditUser(self, name, password, roles, domains, **kw):
+    def userFolderEditUser(self, name, password, roles, domains,
+                           REQUEST=None, **kw):
         """API method for changing user object attributes. Note that not
            all user folder implementations support changing of user object
            attributes."""
         if hasattr(self, '_doChangeUser'):
             return self._doChangeUser(name, password, roles, domains, **kw)
         raise NotImplementedError
+    userFolderEditUser = postonly(userFolderEditUser)
 
-    def userFolderDelUsers(self, names):
+    def userFolderDelUsers(self, names, REQUEST=None):
         """API method for deleting one or more user objects. Note that not
            all user folder implementations support deletion of user objects."""
         if hasattr(self, '_doDelUsers'):
             return self._doDelUsers(names)
         raise NotImplementedError
+    userFolderDelUsers = postonly(userFolderDelUsers)
 
 
     # -----------------------------------
@@ -819,6 +825,7 @@ class BasicUserFolder(Implicit, Persistent, Navigation, Tabs, RoleManager,
             if REQUEST is not None:
                 return self.manage_userFolderProperties(
                     REQUEST, manage_tabs_message='Saved changes.')
+    manage_setUserFolderProperties = postonly(manage_setUserFolderProperties)
 
     def _isPasswordEncrypted(self, pw):
         return AuthEncoding.is_encrypted(pw)
@@ -839,7 +846,6 @@ class BasicUserFolder(Implicit, Persistent, Navigation, Tabs, RoleManager,
 
         return 1
 
-
     def _addUser(self,name,password,confirm,roles,domains,REQUEST=None):
         if not name:
             return MessageDialog(
@@ -874,7 +880,7 @@ class BasicUserFolder(Implicit, Persistent, Navigation, Tabs, RoleManager,
                    action ='manage_main')
         self._doAddUser(name, password, roles, domains)
         if REQUEST: return self._mainUser(self, REQUEST)
-
+    _addUser = postonly(_addUser)
 
     def _changeUser(self,name,password,confirm,roles,domains,REQUEST=None):
         if password == 'password' and confirm == 'pconfirm':
@@ -912,6 +918,7 @@ class BasicUserFolder(Implicit, Persistent, Navigation, Tabs, RoleManager,
                    action ='manage_main')
         self._doChangeUser(name, password, roles, domains)
         if REQUEST: return self._mainUser(self, REQUEST)
+    _changeUser = postonly(_changeUser)
 
     def _delUsers(self,names,REQUEST=None):
         if not names:
@@ -921,6 +928,7 @@ class BasicUserFolder(Implicit, Persistent, Navigation, Tabs, RoleManager,
                    action ='manage_main')
         self._doDelUsers(names)
         if REQUEST: return self._mainUser(self, REQUEST)
+    _delUsers = postonly(_delUsers)
 
     def manage_users(self,submit=None,REQUEST=None,RESPONSE=None):
         """This method handles operations on users for the web based forms
