@@ -4,7 +4,7 @@
 # All Rights Reserved.
 #
 # This software is subject to the provisions of the Zope Public License,
-# Version 2.0 (ZPL).  A copy of the ZPL should accompany this distribution.
+# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
 # THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
 # WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 # WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
@@ -12,6 +12,11 @@
 #
 ##############################################################################
 
+# TODO:  does this script still serve a purpose?  Writing this in 2005,
+# "old btree" doesn't mean much to me.
+
+import transaction
+
 def convert(old, new, threshold=200, f=None):
     "Utility for converting old btree to new"
     n=0
@@ -20,9 +25,9 @@ def convert(old, new, threshold=200, f=None):
         new[k]=v
         n=n+1
         if n > threshold:
-            get_transaction().commit(1)
-            old._p_jar.cacheMinimize(3)
+            transaction.savepoint()
+            old._p_jar.cacheMinimize()
             n=0
 
-    get_transaction().commit(1)
-    old._p_jar.cacheMinimize(3)
+    transaction.savepoint()
+    old._p_jar.cacheMinimize()
