@@ -10,7 +10,7 @@
 # FOR A PARTICULAR PURPOSE
 #
 ##############################################################################
-"$Id: DT_String.py 24763 2004-05-17 05:59:28Z philikon $"
+"$Id: DT_String.py 40315 2005-11-22 14:57:02Z tseaver $"
 
 import os
 import thread
@@ -57,7 +57,7 @@ class String:
 
     parse_error__roles__=()
     def parse_error(self, mess, tag, text, start):
-        raise ParseError, "%s, for tag %s, on line %s of %s<p>" % (
+        raise ParseError, "%s, for tag %s, on line %s of %s" % (
             mess, self.errQuote(tag), len(text[:start].split('\n')),
             self.errQuote(self.__name__))
 
