@@ -12,7 +12,7 @@
 ##############################################################################
 """DTML Method objects.
 
-$Id: DTMLMethod.py 28774 2005-01-10 14:16:41Z jens $
+$Id: DTMLMethod.py 73418 2007-03-21 11:48:43Z mj $
 """
 import History
 from Globals import HTML, DTMLFile, MessageDialog
@@ -29,6 +29,7 @@ from urllib import quote
 import  Globals, sys, Acquisition
 from AccessControl import getSecurityManager
 from AccessControl.DTML import RestrictedDTML
+from AccessControl.requestmethod import postonly
 from Cache import Cacheable
 from zExceptions import Forbidden
 from zExceptions.TracebackSupplement import PathTracebackSupplement
@@ -324,6 +325,7 @@ class DTMLMethod(RestrictedDTML, HTML, Acquisition.Implicit, RoleManager,
         if REQUEST:
             message="Saved changes."
             return self.manage_proxyForm(self,REQUEST,manage_tabs_message=message)
+    manage_proxy = postonly(manage_proxy)
 
     def PrincipiaSearchSource(self):
         "Support for searching - the document's contents are searched."
