@@ -12,7 +12,7 @@
 ##############################################################################
 """Image object
 
-$Id: Image.py 33280 2005-07-12 15:02:15Z tiran $
+$Id: Image.py 65863 2006-03-07 21:54:19Z shh $
 """
 import Globals, struct
 from OFS.content_types import guess_content_type
@@ -219,7 +219,7 @@ class File(Persistent, Implicit, PropertyManager,
                     return True
 
                 ranges = HTTPRangeSupport.expandRanges(ranges, self.size)
-                                
+
                 if len(ranges) == 1:
                     # Easy case, set extra header and return partial set.
                     start, end = ranges[0]
@@ -402,10 +402,10 @@ class File(Persistent, Implicit, PropertyManager,
                 return result
 
         self.ZCacheable_set(None)
-            
+
         data=self.data
         if type(data) is type(''):
-            RESPONSE.setBase(None) 
+            RESPONSE.setBase(None)
             return data
 
         while data is not None:
@@ -516,7 +516,7 @@ class File(Persistent, Implicit, PropertyManager,
 
         # Make sure we have an _p_jar, even if we are a new object, by
         # doing a sub-transaction commit.
-        transaction.savepoint()
+        transaction.savepoint(optimistic=True)
 
         if self._p_jar is None:
             # Ugh
@@ -533,7 +533,7 @@ class File(Persistent, Implicit, PropertyManager,
             if pos < n:
                 pos = 0 # we always want at least n bytes
             seek(pos)
-            
+
             # Create the object and assign it a next pointer
             # in the same transaction, so that there is only
             # a single database update for it.
@@ -542,7 +542,7 @@ class File(Persistent, Implicit, PropertyManager,
             data.next = next
 
             # Save the object so that we can release its memory.
-            transaction.savepoint()
+            transaction.savepoint(optimistic=True)
             data._p_deactivate()
             # The object should be assigned an oid and be a ghost.
             assert data._p_oid is not None
@@ -594,6 +594,8 @@ class File(Persistent, Implicit, PropertyManager,
 
     def manage_FTPget(self):
         """Return body for ftp."""
+        RESPONSE = self.REQUEST.RESPONSE
+
         if self.ZCacheable_isCachingEnabled():
             result = self.ZCacheable_get(default=None)
             if result is not None:
@@ -602,10 +604,19 @@ class File(Persistent, Implicit, PropertyManager,
                 # from FileCacheManager.
                 # the content-length is required here by HTTPResponse, even
                 # though FTP doesn't use it.
-                self.REQUEST.RESPONSE.setHeader('Content-Length', self.size)
+                RESPONSE.setHeader('Content-Length', self.size)
                 return result
-        return str(self.data)
 
+        data = self.data
+        if type(data) is type(''):
+            RESPONSE.setBase(None)
+            return data
+
+        while data is not None:
+            RESPONSE.write(data.data)
+            data = data.next
+
+        return ''
 
 manage_addImageForm=DTMLFile('dtml/imageAdd',globals(),
                              Kind='Image',kind='image')
@@ -770,6 +781,7 @@ class Image(File):
 
         self.ZCacheable_invalidate()
         self.ZCacheable_set(None)
+        self.http__refreshEtag()
 
     def __str__(self):
         return self.tag()
