@@ -13,10 +13,15 @@
 ##############################################################################
 """Site error log product.
 
-$Id: __init__.py,v 1.3 2002/08/14 22:25:11 mj Exp $
+$Id: __init__.py 27328 2004-08-29 14:00:53Z ctheune $
 """
 
 import SiteErrorLog
+from ImageFile import ImageFile
+
+misc_={
+    'ok.gif': ImageFile('www/ok.gif', globals()),
+}
 
 def initialize(context):
     context.registerClass(SiteErrorLog.SiteErrorLog,
