@@ -13,7 +13,7 @@
 """
 Simple ZODB-based transient object implementation.
 
-$Id: TransientObject.py 27630 2004-09-18 03:27:57Z chrism $
+$Id: TransientObject.py 38709 2005-10-01 13:20:29Z jens $
 """
 
 __version__='$Revision: 1.9.68.5 $'[11:-2]
@@ -256,8 +256,8 @@ class TransientObject(Persistent, Implicit):
         return "%s%s" % (t, d)
 
     def __repr__(self):
-        return "id: %s, token: %s, contents: %s" % (
-            self.id, self.token, `self.items()`
+        return "id: %s, token: %s, contents keys: %s" % (
+            self.id, self.token, `self.keys()`
             )
 
 def lastmodified_sort(d1, d2):
