@@ -11,14 +11,18 @@
 # FOR A PARTICULAR PURPOSE.
 #
 ##############################################################################
+"""ZCTextIndex unit tests.
+
+$Id: testZCTextIndex.py 39790 2005-10-31 20:49:11Z yuppie $
+"""
+
+import unittest
+
+import re
 
-from Interface.Verify import verifyClass
 import Acquisition
 from zExceptions import NotFound
 
-from Products.PluginIndexes.common.PluggableIndex import \
-     PluggableIndexInterface
-
 from Products.ZCTextIndex.ZCTextIndex import ZCTextIndex, PLexicon
 from Products.ZCTextIndex.tests import \
      testIndex, testQueryEngine, testQueryParser
@@ -32,8 +36,6 @@ from Products.ZCTextIndex.QueryParser import QueryParser
 from Products.ZCTextIndex.StopDict import get_stopdict
 from Products.ZCTextIndex.ParseTree import ParseError
 
-import re
-import unittest
 
 class Indexable:
     def __init__(self, text):
@@ -151,6 +153,29 @@ class ZCIndexTestsBase:
         nbest, total = zc_index.query('foo alpha gamma')
         self.assertEqual(len(nbest), 0)
 
+    def testListAttributes(self):
+        lexicon = PLexicon('lexicon', '',
+                            Splitter(),
+                            CaseNormalizer(),
+                            StopWordRemover())
+        caller = LexiconHolder(self.lexicon)
+        zc_index = ZCTextIndex('name',
+                                None,
+                                caller,
+                                self.IndexFactory,
+                               'text1,text2',
+                               'lexicon')
+        doc = Indexable2('Hello Tim', \
+                         ['Now is the winter of our discontent',
+                          'Made glorious summer by this sun of York', ])
+        zc_index.index_object(1, doc)
+        nbest, total = zc_index.query('glorious')
+        self.assertEqual(len(nbest), 1)
+        nbest, total = zc_index.query('York Tim')
+        self.assertEqual(len(nbest), 1)
+        nbest, total = zc_index.query('Tuesday Tim York')
+        self.assertEqual(len(nbest), 0)
+
     def testStopWords(self):
         # the only non-stopword is question
         text = ("to be or not to be "
@@ -227,9 +252,21 @@ class CosineIndexTests(ZCIndexTestsBase, testIndex.CosineIndexTest):
     # Gigabytes, pp. 180-188.  This test peeks into many internals of the
     # cosine indexer.
 
-    def testInterface(self):
+    def test_z2interfaces(self):
+        from Interface.Verify import verifyClass
+        from Products.PluginIndexes.common.PluggableIndex \
+                import PluggableIndexInterface
+
         verifyClass(PluggableIndexInterface, ZCTextIndex)
 
+    def test_z3interfaces(self):
+        from Products.PluginIndexes.interfaces import IPluggableIndex
+        from Products.ZCTextIndex.interfaces import IZCTextIndex
+        from zope.interface.verify import verifyClass
+
+        verifyClass(IPluggableIndex, ZCTextIndex)
+        verifyClass(IZCTextIndex, ZCTextIndex)
+
     def testRanking(self):
         self.words = ["cold", "days", "eat", "hot", "lot", "nine", "old",
                       "pease", "porridge", "pot"]
@@ -525,18 +562,30 @@ class QueryTestsBase(testQueryEngine.TestQueryEngine,
         dictkeys.sort()
         self.assertEqual(setkeys, dictkeys)
 
+
 class CosineQueryTests(QueryTestsBase):
     IndexFactory = CosineIndex
 
+
 class OkapiQueryTests(QueryTestsBase):
     IndexFactory = OkapiIndex
 
-############################################################################
+
+class PLexiconTests(unittest.TestCase):
+
+    def test_z3interfaces(self):
+        from Products.ZCTextIndex.interfaces import ILexicon
+        from Products.ZCTextIndex.interfaces import IZCLexicon
+        from zope.interface.verify import verifyClass
+
+        verifyClass(ILexicon, PLexicon)
+        verifyClass(IZCLexicon, PLexicon)
+
 
 def test_suite():
     s = unittest.TestSuite()
     for klass in (CosineIndexTests, OkapiIndexTests,
-                  CosineQueryTests, OkapiQueryTests):
+                  CosineQueryTests, OkapiQueryTests, PLexiconTests):
         s.addTest(unittest.makeSuite(klass))
     return s
 
