@@ -19,21 +19,22 @@ Usage:
     import makerequest
     app = makerequest.makerequest(Zope2.app())
 
-$Id: makerequest.py 28991 2005-01-31 15:45:46Z jim $
+$Id: makerequest.py 68149 2006-05-16 13:47:31Z tseaver $
 
 """
 
 import os
-from os import environ
 from sys import stdin, stdout
 from ZPublisher.HTTPRequest import HTTPRequest
 from ZPublisher.HTTPResponse import HTTPResponse
 from ZPublisher.BaseRequest import RequestContainer
 
-def makerequest(app, stdout=stdout):
+def makerequest(app, stdout=stdout, **kw):
     resp = HTTPResponse(stdout=stdout)
-    environ['SERVER_NAME']='foo'
-    environ['SERVER_PORT']='80'
-    environ['REQUEST_METHOD'] = 'GET'
-    req = HTTPRequest(stdin, environ, resp)
+    env = os.environ.copy()
+    env['SERVER_NAME']='foo'
+    env['SERVER_PORT']='80'
+    env['REQUEST_METHOD'] = 'GET'
+    env.update(kw)
+    req = HTTPRequest(stdin, env, resp)
     return app.__of__(RequestContainer(REQUEST = req))
