@@ -4,7 +4,7 @@
 # All Rights Reserved.
 #
 # This software is subject to the provisions of the Zope Public License,
-# Version 2.0 (ZPL).  A copy of the ZPL should accompany this distribution.
+# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
 # THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
 # WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 # WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
@@ -16,7 +16,7 @@
 This server acts as a front-end for one or more real storages, like
 file storage or Berkeley storage.
 
-XXX Need some basic access control-- a declaration of the methods
+TODO:  Need some basic access control-- a declaration of the methods
 exported for invocation by the server.
 """
 
@@ -26,6 +26,9 @@ import os
 import sys
 import threading
 import time
+import logging
+
+import transaction
 
 from ZEO import ClientStub
 from ZEO.CommitLog import CommitLog
@@ -35,24 +38,30 @@ from ZEO.zrpc.connection import ManagedServerConnection, Delay, MTDelay
 from ZEO.zrpc.trigger import trigger
 from ZEO.Exceptions import AuthError
 
-import zLOG
 from ZODB.ConflictResolution import ResolvedSerial
 from ZODB.POSException import StorageError, StorageTransactionError
 from ZODB.POSException import TransactionError, ReadOnlyError, ConflictError
-from ZODB.referencesf import referencesf
-from ZODB.Transaction import Transaction
+from ZODB.serialize import referencesf
 from ZODB.utils import u64, oid_repr
+from ZODB.loglevels import BLATHER
 
-_label = "ZSS" # Default label used for logging.
+logger = logging.getLogger('ZEO.StorageServer')
+
+# TODO:  This used to say "ZSS", which is now implied in the logger name.
+# Can this be either set to str(os.getpid()) (if that makes sense) or removed?
+_label = "" # default label used for logging.
 
 def set_label():
     """Internal helper to reset the logging label (e.g. after fork())."""
     global _label
-    _label = "ZSS:%s" % os.getpid()
+    _label = "%s" % os.getpid()
 
-def log(message, level=zLOG.INFO, label=None, error=None):
-    """Internal helper to log a message using zLOG."""
-    zLOG.LOG(label or _label, level, message, error=error)
+def log(message, level=logging.INFO, label=None, exc_info=False):
+    """Internal helper to log a message."""
+    label = label or _label
+    if label:
+        message = "(%s) %s" % (label, message)
+    logger.log(level, message, exc_info=exc_info)
 
 class StorageServerError(StorageError):
     """Error reported when an unpickleable exception is raised."""
@@ -130,8 +139,8 @@ class ZEOStorage:
         name = self.__class__.__name__
         return "<%s %X trans=%s s_trans=%s>" % (name, id(self), tid, stid)
 
-    def log(self, msg, level=zLOG.INFO, error=None):
-        zLOG.LOG(self.log_label, level, msg, error=error)
+    def log(self, msg, level=logging.INFO, exc_info=False):
+        log(msg, level=level, label=self.log_label, exc_info=exc_info)
 
     def setup_delegation(self):
         """Delegate several methods to the storage"""
@@ -163,7 +172,8 @@ class ZEOStorage:
             raise ReadOnlyError()
         if self.transaction is None:
             caller = sys._getframe().f_back.f_code.co_name
-            self.log("no current transaction: %s()" % caller, zLOG.PROBLEM)
+            self.log("no current transaction: %s()" % caller,
+                     level=logging.WARNING)
             if exc is not None:
                 raise exc(None, tid)
             else:
@@ -172,7 +182,7 @@ class ZEOStorage:
             caller = sys._getframe().f_back.f_code.co_name
             self.log("%s(%s) invalid; current transaction = %s" %
                      (caller, repr(tid), repr(self.transaction.id)),
-                     zLOG.PROBLEM)
+                     logging.WARNING)
             if exc is not None:
                 raise exc(self.transaction.id, tid)
             else:
@@ -222,8 +232,6 @@ class ZEOStorage:
                 'name': self.storage.getName(),
                 'supportsUndo': self.storage.supportsUndo(),
                 'supportsVersions': self.storage.supportsVersions(),
-                'supportsTransactionalUndo':
-                self.storage.supportsTransactionalUndo(),
                 'extensionMethods': self.getExtensionMethods(),
                 }
 
@@ -235,6 +243,14 @@ class ZEOStorage:
     def getExtensionMethods(self):
         return self._extensions
 
+    def loadEx(self, oid, version):
+        self.stats.loads += 1
+        return self.storage.loadEx(oid, version)
+
+    def loadBefore(self, oid, tid):
+        self.stats.loads += 1
+        return self.storage.loadBefore(oid, tid)
+
     def zeoLoad(self, oid):
         self.stats.loads += 1
         v = self.storage.modifiedInVersion(oid)
@@ -260,15 +276,29 @@ class ZEOStorage:
                  % (len(invlist), u64(invtid)))
         return invtid, invlist
 
+    def verify(self, oid, version, tid):
+        try:
+            t = self.storage.getTid(oid)
+        except KeyError:
+            self.client.invalidateVerify((oid, ""))
+        else:
+            if tid != t:
+                # This will invalidate non-version data when the
+                # client only has invalid version data.  Since this is
+                # an uncommon case, we avoid the cost of checking
+                # whether the serial number matches the current
+                # non-version data.
+                self.client.invalidateVerify((oid, version))
+
     def zeoVerify(self, oid, s, sv):
         if not self.verifying:
             self.verifying = 1
             self.stats.verifying_clients += 1
         try:
-            os = self.storage.getSerial(oid)
+            os = self.storage.getTid(oid)
         except KeyError:
             self.client.invalidateVerify((oid, ''))
-            # XXX It's not clear what we should do now.  The KeyError
+            # It's not clear what we should do now.  The KeyError
             # could be caused by an object uncreation, in which case
             # invalidation is right.  It could be an application bug
             # that left a dangling reference, in which case it's bad.
@@ -326,16 +356,6 @@ class ZEOStorage:
             n = 1
         return [self.storage.new_oid() for i in range(n)]
 
-    def undo(self, transaction_id):
-        if self.read_only:
-            raise ReadOnlyError()
-        oids = self.storage.undo(transaction_id)
-        if oids:
-            self.server.invalidate(self, self.storage_id, None,
-                                   map(lambda oid: (oid, ''), oids))
-            return oids
-        return ()
-
     # undoLog and undoInfo are potentially slow methods
 
     def undoInfo(self, first, last, spec):
@@ -344,7 +364,7 @@ class ZEOStorage:
     def undoLog(self, first, last):
         return run_in_thread(self.storage.undoLog, first, last)
 
-    def tpc_begin(self, id, user, description, ext, tid, status):
+    def tpc_begin(self, id, user, description, ext, tid=None, status=" "):
         if self.read_only:
             raise ReadOnlyError()
         if self.transaction is not None:
@@ -355,7 +375,7 @@ class ZEOStorage:
                 raise StorageTransactionError("Multiple simultaneous tpc_begin"
                                               " requests from one client.")
 
-        self.transaction = t = Transaction()
+        self.transaction = t = transaction.Transaction()
         t.id = id
         t.user = user
         t.description = description
@@ -401,7 +421,7 @@ class ZEOStorage:
             self.locked = 0
             self.timeout.end(self)
             self.stats.lock_time = None
-            self.log("Transaction released storage lock")
+            self.log("Transaction released storage lock", BLATHER)
             # _handle_waiting() can start another transaction (by
             # restarting a waiting one) so must be done last
             self._handle_waiting()
@@ -458,12 +478,12 @@ class ZEOStorage:
         else:
             return self._wait(lambda: self._commitVersion(src, dest))
 
-    def transactionalUndo(self, trans_id, id):
+    def undo(self, trans_id, id):
         self._check_tid(id, exc=StorageTransactionError)
         if self.locked:
-            return self._transactionalUndo(trans_id)
+            return self._undo(trans_id)
         else:
-            return self._wait(lambda: self._transactionalUndo(trans_id))
+            return self._wait(lambda: self._undo(trans_id))
 
     def _tpc_begin(self, txn, tid, status):
         self.locked = 1
@@ -483,13 +503,11 @@ class ZEOStorage:
             if isinstance(err, ConflictError):
                 self.stats.conflicts += 1
                 self.log("conflict error oid=%s msg=%s" %
-                         (oid_repr(oid), str(err)), zLOG.BLATHER)
+                         (oid_repr(oid), str(err)), BLATHER)
             if not isinstance(err, TransactionError):
                 # Unexpected errors are logged and passed to the client
-                exc_info = sys.exc_info()
-                self.log("store error: %s, %s" % exc_info[:2],
-                         zLOG.ERROR, error=exc_info)
-                del exc_info
+                self.log("store error: %s, %s" % sys.exc_info()[:2],
+                         logging.ERROR, exc_info=True)
             # Try to pickle the exception.  If it can't be pickled,
             # the RPC response would fail, so use something else.
             pickler = cPickle.Pickler()
@@ -498,7 +516,7 @@ class ZEOStorage:
                 pickler.dump(err, 1)
             except:
                 msg = "Couldn't pickle storage exception: %s" % repr(err)
-                self.log(msg, zLOG.ERROR)
+                self.log(msg, logging.ERROR)
                 err = StorageServerError(msg)
             # The exception is reported back as newserial for this oid
             newserial = err
@@ -507,7 +525,7 @@ class ZEOStorage:
                 self.invalidated.append((oid, version))
         if newserial == ResolvedSerial:
             self.stats.conflicts_resolved += 1
-            self.log("conflict resolved oid=%s" % oid_repr(oid), zLOG.BLATHER)
+            self.log("conflict resolved oid=%s" % oid_repr(oid), BLATHER)
         self.serials.append((oid, newserial))
         return err is None
 
@@ -521,32 +539,32 @@ class ZEOStorage:
         return self.storage.tpc_vote(self.transaction)
 
     def _abortVersion(self, src):
-        oids = self.storage.abortVersion(src, self.transaction)
+        tid, oids = self.storage.abortVersion(src, self.transaction)
         inv = [(oid, src) for oid in oids]
         self.invalidated.extend(inv)
-        return oids
+        return tid, oids
 
     def _commitVersion(self, src, dest):
-        oids = self.storage.commitVersion(src, dest, self.transaction)
+        tid, oids = self.storage.commitVersion(src, dest, self.transaction)
         inv = [(oid, dest) for oid in oids]
         self.invalidated.extend(inv)
         if dest:
             inv = [(oid, src) for oid in oids]
             self.invalidated.extend(inv)
-        return oids
+        return tid, oids
 
-    def _transactionalUndo(self, trans_id):
-        oids = self.storage.transactionalUndo(trans_id, self.transaction)
+    def _undo(self, trans_id):
+        tid, oids = self.storage.undo(trans_id, self.transaction)
         inv = [(oid, None) for oid in oids]
         self.invalidated.extend(inv)
-        return oids
+        return tid, oids
 
     # When a delayed transaction is restarted, the dance is
     # complicated.  The restart occurs when one ZEOStorage instance
     # finishes as a transaction and finds another instance is in the
     # _waiting list.
 
-    # XXX It might be better to have a mechanism to explicitly send
+    # It might be better to have a mechanism to explicitly send
     # the finishing transaction's reply before restarting the waiting
     # transaction.  If the restart takes a long time, the previous
     # client will be blocked until it finishes.
@@ -561,7 +579,7 @@ class ZEOStorage:
                      "Clients waiting: %d." % len(self.storage._waiting))
             return d
         else:
-            self.log("Transaction acquired storage lock.", zLOG.BLATHER)
+            self.log("Transaction acquired storage lock.", BLATHER)
             return self._restart()
 
     def _restart(self, delay=None):
@@ -571,7 +589,7 @@ class ZEOStorage:
         else:
             template = "Preparing to commit transaction: %d objects, %d bytes"
         self.log(template % (self.txnlog.stores, self.txnlog.size()),
-                 level=zLOG.BLATHER)
+                 level=BLATHER)
         self._tpc_begin(self.transaction, self.tid, self.status)
         loads, loader = self.txnlog.get_loader()
         for i in range(loads):
@@ -604,7 +622,7 @@ class ZEOStorage:
             zeo_storage._restart(delay)
         except:
             self.log("Unexpected error handling waiting transaction",
-                     level=zLOG.WARNING, error=sys.exc_info())
+                     level=logging.WARNING, exc_info=True)
             zeo_storage.connection.close()
             return 0
         else:
@@ -783,7 +801,7 @@ class StorageServer:
             zstorage = self.ZEOStorageClass(self, self.read_only)
 
         c = self.ManagedServerConnectionClass(sock, addr, zstorage, self)
-        log("new connection %s: %s" % (addr, `c`))
+        log("new connection %s: %s" % (addr, repr(c)))
         return c
 
     def register_connection(self, storage_id, conn):
