@@ -10,10 +10,10 @@
 # FOR A PARTICULAR PURPOSE
 #
 ##############################################################################
-__doc__='''Package of template utility classes and functions.
+"""Package of template utility classes and functions.
 
-$Id: __init__.py,v 1.6.66.1 2005/01/27 14:55:28 shh Exp $'''
-__version__='$Revision: 1.6.66.1 $'[11:-2]
+$Id: __init__.py 28963 2005-01-27 14:56:22Z shh $
+"""
 
 from Iterator import Iterator
 from Tree import encodeExpansion, decodeExpansion, a2b, b2a
@@ -22,5 +22,5 @@ from SimpleTree import SimpleTreeMaker
 __allow_access_to_unprotected_subobjects__ = 1
 __roles__ = None
 
-from Zope import Batch, TreeMaker, SimpleTreeMaker, LazyFilter
-from Zope import url_query, make_query, make_hidden_input
+from ZTUtils.Zope import Batch, TreeMaker, SimpleTreeMaker, LazyFilter
+from ZTUtils.Zope import url_query, make_query, make_hidden_input
