@@ -2,7 +2,7 @@
 
 """Print a text summary of the contents of a FileStorage."""
 
-from ZODB.fsdump import fsdump
+from ZODB.FileStorage.fsdump import fsdump
 
 if __name__ == "__main__":
     import sys
